<?php
// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

final class LiviconsEvolutionInElementor {

	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	private static $_instance = null;

	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'init' ] );
	}

	/**
	 * Initializing
	 *
	 * Do the actions only after Elementor is loaded.
	 * Checks for basic requirements, if one check fail don't continue.
	 *
	 * Fired by `plugins_loaded` action hook.
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			//if not, exit
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Add Plugin actions
		add_action( 'elementor/editor/before_enqueue_scripts', 'livicons_evolution_dialog' );
		add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'load_assets' ] );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'livicons-evo' ),
			'<strong>LivIcons Evolution</strong>',
			'<strong>Elementor</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}


	/**
	 * Load Assets
	 *
	 */
	public function load_assets() {

		wp_register_style(
			'livicons-evolution-styles',
			LIVICONS_EVOLUTION_URL . 'assets/css/LivIconsEvo.WP.css',
			array( 'elementor-editor' ),
			LIVICONS_EVOLUTION_VERSION
		);
		wp_register_style(
			'livicons-evolution-elementor-css',
			LIVICONS_EVOLUTION_URL . 'assets/css/LivIconsEvo.elementor.css',
			array( 'elementor-editor', 'livicons-evolution-styles' ),
			LIVICONS_EVOLUTION_VERSION
		);
		wp_register_style(
			'livicons-evolution-dialog-css',
			LIVICONS_EVOLUTION_URL . 'assets/css/LivIconsEvo.dialog.css',
			array( 'elementor-editor', 'livicons-evolution-styles', 'livicons-evolution-elementor-css' ),
			LIVICONS_EVOLUTION_VERSION
		);

		wp_register_script(
			'livicons-evolution-tools',
			LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.WP.tools.js',
			array( 'elementor-editor' ),
			LIVICONS_EVOLUTION_VERSION,
			true
		);
		wp_register_script(
			'livicons-evolution-defaults',
			LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.WP.defaults.js',
			array( 'elementor-editor', 'jquery' ),
			get_option( 'livicons_evolution_dynamic_string', '' ),
			true
		);
		wp_register_script(
			'livicons-evolution-core',
			LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.WP.min.js',
			array( 'elementor-editor', 'jquery', 'livicons-evolution-tools', 'livicons-evolution-defaults' ),
			LIVICONS_EVOLUTION_VERSION,
			true
		);
		wp_register_script(
			'livicons-evolution-elementor-js',
			LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.elementor.js',
			array( 'elementor-editor', 'livicons-evolution-core' ),
			LIVICONS_EVOLUTION_VERSION,
			true
		);
		wp_register_script(
			'livicons-evolution-dialog-js',
			LIVICONS_EVOLUTION_URL . 'assets/js/LivIconsEvo.dialog.js',
			array( 'elementor-editor', 'livicons-evolution-core', 'livicons-evolution-elementor-js' ),
			LIVICONS_EVOLUTION_VERSION,
			true
		);
		wp_localize_script( 'livicons-evolution-dialog-js', 'translate_confirms_in_dialog',
			array( 
				'reset_options_msg' => esc_html__( 'Are you sure you want to reset these options?', 'livicons-evo' )
			)
		);

		wp_enqueue_style( 'livicons-evolution-styles' );
		wp_enqueue_style( 'livicons-evolution-elementor-css' );
		wp_enqueue_style( 'livicons-evolution-dialog-css' );

		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'livicons-evolution-tools' );
		wp_enqueue_script( 'livicons-evolution-defaults' );
		wp_enqueue_script( 'livicons-evolution-core' );
		wp_enqueue_script( 'livicons-evolution-dialog-js' );
		wp_enqueue_script( 'livicons-evolution-elementor-js' );

	}

}

LiviconsEvolutionInElementor::instance();